@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@
 #include <QSignalSpy>
 #include <QTemporaryFile>
 #include <QTest>
-//#define REMOVE_CREATED_ZIP_FILE 1
+// #define REMOVE_CREATED_ZIP_FILE 1
 
 TestExportFile::TestExportFile(QObject *parent)
     : QObject(parent)
@@ -50,8 +50,8 @@ void TestExportFile::start()
 {
     // Don't use setTestModeEnabled otherwise we can set env
     // QStandardPaths::setTestModeEnabled(true);
-    qputenv("XDG_DATA_HOME", mPathConfig + "/share");
-    qputenv("XDG_CONFIG_HOME", mPathConfig + "/config");
+    qputenv("XDG_DATA_HOME", QByteArray(mPathConfig + "/share"));
+    qputenv("XDG_CONFIG_HOME", QByteArray(mPathConfig + "/config"));
 
     // TODO fix file name.
     Utils::addVersion(mArchiveStorage->archive());
